Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(108)

Unified Diff: runtime/vm/dart_entry_test.cc

Issue 13638019: Implement write barrier on ARM. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/assembler_test.cc ('k') | runtime/vm/stub_code_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/dart_entry_test.cc
===================================================================
--- runtime/vm/dart_entry_test.cc (revision 21081)
+++ runtime/vm/dart_entry_test.cc (working copy)
@@ -14,8 +14,10 @@
namespace dart {
-// Only ia32 and x64 can run execution tests.
-#if defined(TARGET_ARCH_IA32) || defined(TARGET_ARCH_X64)
+// Only IA32, X64, and ARM can run execution tests.
+#if defined(TARGET_ARCH_IA32) || \
+ defined(TARGET_ARCH_X64) || \
+ defined(TARGET_ARCH_ARM)
TEST_CASE(DartEntry) {
const char* kScriptChars =
@@ -113,6 +115,6 @@
EXPECT_SUBSTRING("++++", Error::Cast(retval).ToErrorCString());
}
-#endif // TARGET_ARCH_IA32 || TARGET_ARCH_X64.
+#endif // TARGET_ARCH_IA32 || TARGET_ARCH_X64 || TARGET_ARCH_ARM
} // namespace dart
« no previous file with comments | « runtime/vm/assembler_test.cc ('k') | runtime/vm/stub_code_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698